@@ -43,7 +43,6 @@ class InMemoryDatasetHandle:
         component: Optional[str] = None,
         parameters: Optional[dict] = None,
         storageClass: str | StorageClass | None = None,
-        **kwargs: dict,
     ) -> Any:
         """Retrieves the dataset pointed to by this handle
 
@@ -66,10 +65,6 @@ class InMemoryDatasetHandle:
             the type stored. Specifying a read `StorageClass` can force a
             different type to be returned.
             This type must be compatible with the original type.
-        **kwargs
-            This argument is deprecated and only exists to support legacy
-            gen2 butler code during migration. It is completely ignored
-            and will be removed in the future.
 
         Returns
         -------
